@@ -116,6 +116,20 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
             elif custom_command in self._custom_commands:
                 del self._custom_commands[custom_command]
 
+    def _cmd_audio_state(self):
+        """Get the command used to retrieve the current audio state for this device.
+
+        Returns
+        -------
+        str
+            The device-specific ADB shell command used to determine the current audio state
+
+        """
+        if constants.CUSTOM_AUDIO_STATE in self._custom_commands:
+            return self._custom_commands[constants.CUSTOM_AUDIO_STATE]
+
+        return constants.CMD_AUDIO_STATE
+
     def _cmd_current_app(self):
         """Get the command used to retrieve the current app for this device.
 
@@ -160,6 +174,20 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
 
         return constants.CMD_CURRENT_APP_MEDIA_SESSION_STATE
 
+    def _cmd_hdmi_input(self):
+        """Get the command used to retrieve the current HDMI input for this device.
+
+        Returns
+        -------
+        str
+            The device-specific ADB shell command used to determine the current HDMI input
+
+        """
+        if constants.CUSTOM_HDMI_INPUT in self._custom_commands:
+            return self._custom_commands[constants.CUSTOM_HDMI_INPUT]
+
+        return constants.CMD_HDMI_INPUT
+
     def _cmd_launch_app(self, app):
         """Get the command to launch the specified app for this device.
 
@@ -185,6 +213,9 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         ):
             return constants.CMD_LAUNCH_APP_GOOGLE_TV.format(app)
 
+        if self.DEVICE_ENUM == constants.DeviceEnum.FIRETV:
+            return constants.CMD_LAUNCH_APP_FIRETV.format(app)
+
         return constants.CMD_LAUNCH_APP.format(app)
 
     def _cmd_running_apps(self):
@@ -468,12 +499,12 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
 
     @staticmethod
     def _audio_state(audio_state_response):
-        """Parse the :meth:`audio_state` property from the output of the command :py:const:`androidtv.constants.CMD_AUDIO_STATE`.
+        """Parse the :meth:`audio_state` property from the ADB shell output.
 
         Parameters
         ----------
         audio_state_response : str, None
-            The output of the command :py:const:`androidtv.constants.CMD_AUDIO_STATE`
+            The output from the ADB command `androidtv.basetv.basetv.BaseTV._cmd_audio_state``
 
         Returns
         -------
@@ -541,12 +572,12 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
 
     @staticmethod
     def _get_hdmi_input(hdmi_response):
-        """Get the HDMI input from the output of :py:const:`androidtv.constants.CMD_HDMI_INPUT`.
+        """Get the HDMI input from the from the ADB shell output`.
 
         Parameters
         ----------
         hdmi_response : str, None
-            The output of :py:const:`androidtv.constants.CMD_HDMI_INPUT`
+            The output from the ADB command `androidtv.basetv.basetv.BaseTV._cmd_hdmi_input``
 
         Returns
         -------
