@@ -31,19 +31,24 @@ class DeviceEnum(IntEnum):
 
 
 # Intents
-INTENT_LAUNCH = "android.intent.category.LAUNCHER"
+INTENT_LAUNCH = "android.intent.category.LEANBACK_LAUNCHER"
+INTENT_LAUNCH_FIRETV = "android.intent.category.LAUNCHER"
 INTENT_HOME = "android.intent.category.HOME"
 
 # Customizable commands
+CUSTOM_AUDIO_STATE = "audio_state"
 CUSTOM_CURRENT_APP = "current_app"
 CUSTOM_CURRENT_APP_MEDIA_SESSION_STATE = "current_app_media_session_state"
+CUSTOM_HDMI_INPUT = "hdmi_input"
 CUSTOM_LAUNCH_APP = "launch_app"
 CUSTOM_RUNNING_APPS = "running_apps"
 CUSTOM_TURN_OFF = "turn_off"
 CUSTOM_TURN_ON = "turn_on"
 CUSTOMIZABLE_COMMANDS = {
+    CUSTOM_AUDIO_STATE,
     CUSTOM_CURRENT_APP,
     CUSTOM_CURRENT_APP_MEDIA_SESSION_STATE,
+    CUSTOM_HDMI_INPUT,
     CUSTOM_LAUNCH_APP,
     CUSTOM_RUNNING_APPS,
     CUSTOM_TURN_OFF,
@@ -52,7 +57,9 @@ CUSTOMIZABLE_COMMANDS = {
 
 #: The subset of `CUSTOMIZABLE_COMMANDS` that is potentially used in the ``update()`` method
 HA_CUSTOMIZABLE_COMMANDS = (
+    CUSTOM_AUDIO_STATE,
     CUSTOM_CURRENT_APP_MEDIA_SESSION_STATE,
+    CUSTOM_HDMI_INPUT,
     CUSTOM_LAUNCH_APP,
     CUSTOM_RUNNING_APPS,
     CUSTOM_TURN_OFF,
@@ -100,11 +107,21 @@ CMD_LAUNCH_APP_CONDITION = (
     "if [ $CURRENT_APP != '{0}' ]; then monkey -p {0} -c " + INTENT_LAUNCH + " --pct-syskeys 0 1; fi"
 )
 
+#: Launch an app if it is not already the current app (assumes the variable ``CURRENT_APP`` has already been set) on a Fire TV
+CMD_LAUNCH_APP_CONDITION_FIRETV = (
+    "if [ $CURRENT_APP != '{0}' ]; then monkey -p {0} -c " + INTENT_LAUNCH_FIRETV + " --pct-syskeys 0 1; fi"
+)
+
 #: Launch an app if it is not already the current app
 CMD_LAUNCH_APP = (
     CMD_DEFINE_CURRENT_APP_VARIABLE.replace("{", "{{").replace("}", "}}") + " && " + CMD_LAUNCH_APP_CONDITION
 )
 
+#: Launch an app on a Fire TV device
+CMD_LAUNCH_APP_FIRETV = (
+    CMD_DEFINE_CURRENT_APP_VARIABLE.replace("{", "{{").replace("}", "}}") + " && " + CMD_LAUNCH_APP_CONDITION_FIRETV
+)
+
 #: Launch an app on a Google TV device
 CMD_LAUNCH_APP_GOOGLE_TV = (
     CMD_DEFINE_CURRENT_APP_VARIABLE_GOOGLE_TV.replace("{", "{{").replace("}", "}}") + " && " + CMD_LAUNCH_APP_CONDITION
@@ -397,10 +414,10 @@ APP_NLZIET = "nl.nlziet"
 APP_NOS = "nl.nos.app"
 APP_NPO = "nl.uitzendinggemist"
 APP_OCS = "com.orange.ocsgo"
-APP_PLAY_GAMES = "com.google.android.games"
+APP_PLAY_GAMES = "com.google.android.play.games"
 APP_PLAY_MUSIC = "com.google.android.music"
 APP_PLAY_STORE = "com.android.vending"
-APP_PLAY_VIDEOS = "com.android.videos"
+APP_PLAY_VIDEOS = "com.google.android.videos"
 APP_PLEX = "com.plexapp.android"
 APP_PRIME_VIDEO = "com.amazon.amazonvideo.livingroom"
 APP_PRIME_VIDEO_FIRETV = "com.amazon.firebat"
